| Title: | 'Asio' C++ Header Files |
|---|---|
| Description: | 'Asio' is a cross-platform C++ library for network and low-level I/O programming that provides developers with a consistent asynchronous model using a modern C++ approach. It is also included in Boost but requires linking when used with Boost. Standalone it can be used header-only (provided a recent compiler). 'Asio' is written and maintained by Christopher M. Kohlhoff, and released under the 'Boost Software License', Version 1.0. |
| Authors: | Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>), Christopher M. Kohlhoff [aut] (Author of Asio) |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | BSL-1.0 |
| Version: | 1.30.2-1 |
| Built: | 2026-05-24 10:07:19 UTC |
| Source: | https://github.com/eddelbuettel/asioheaders |
Asio is a cross-platform C++ library for network and low-level I/O programming that provides developers with a consistent asynchronous model using a modern C++ approach.
Asio is a cross-platform C++ library for network and low-level I/O programming that provides developers with a consistent asynchronous model using a modern C++ approach.
Asio is also included in Boost but requires linking when used with Boost. Standalone it can be used header-only provided a recent-enough compiler.
Bug reports can also be registered at the GitHub issue tracker at https://github.com/eddelbuettel/asioheaders/issues.
Dirk Eddelbuettel
Maintainer: Dirk Eddelbuettel <[email protected]>
The https://github.com/eddelbuettel/rcppasioexample package
provides a simple illustration and example of using this package. It
can be used to both assert compiler and setup are working correctly, and form
a basis to extend work from. Generally speaking, only a 'LinkingTo: AsioHeaders'
should is needed, plus on Windows only a very simply link instruction in
src/Makevars.win adding PKG_LIBS = -lwsock32
-lws2_32.
# None# None